@@ -3,7 +3,7 @@ function(file)
 {
     x <- PDF_doc_from_file(file)
 
-    y <- .Call("PDF_text", x$doc)
+    y <- .Call(Rpoppler_PDF_text, x$doc)
 
     y
 
